pub fn declassify_mut_slice<T>(x: T) -> TExpand description
Classify a mutable slice (identity) We define a separate function for this because hax has limited support for &mut-returning functions
pub fn declassify_mut_slice<T>(x: T) -> TClassify a mutable slice (identity) We define a separate function for this because hax has limited support for &mut-returning functions